Learn R Programming

Rtumblr (version 0.1.1)

get_blog_avatar: Retrieve a Blog Avatar You can get a blog's avatar in 9 different sizes

Description

Retrieve a Blog Avatar You can get a blog's avatar in 9 different sizes

Usage

get_blog_avatar(blog, size = 64)

Value

png of avatar

Arguments

blog

name of the blog

size

Integer. The size of the avatar (square, one value for both length and width). Must be one of the values: 16, 24, 30, 40, 48, 64, 96, 128, 512

Examples

Run this code
if (FALSE) {
avatar <- get_blog_avatar("schochastics")
png::writePNG("avatar_schochastics.png")
}

Run the code above in your browser using DataLab