Learn R Programming

Rtumblr (version 0.1.1)

get_blog_info: Retrieve Blog Info

Description

This method returns general information about the blog, such as the title, number of posts, and other high-level data.

Usage

get_blog_info(blog, api_key = NULL)

Value

tibble of information about blog

Arguments

blog

name of the blog

api_key

app consumer key. If NULL, attempts to load from the environment variable RTUMBLR_TOKEN

Examples

Run this code
if (FALSE) {
get_blog_info("schochastics")
}

Run the code above in your browser using DataLab