Learn R Programming

Rtumblr (version 0.1.1)

get_blog_blocks: Retrieve Blogs Blocks

Description

Get the blogs that the requested blog is currently blocking. The requesting user must be an admin of the blog to retrieve this list. Note that this endpoint is rate limited to 60 requests per minute.

Usage

get_blog_blocks(blog, limit = 20, offset = 0, app_credentials = NULL)

Value

tibble of blocked blogs

Arguments

blog

name of the blog

limit

number of blocks to retrieve (1-20)

offset

block number to start at (default 0)

app_credentials

a named list containing the consumer key and consumer secret. If NULL, attempts to load from an env variable

Examples

Run this code
if (FALSE) {
# replace "your-blog-name" with your Tumblr username
get_blog_blocks(blog = "your-blog-name")
}

Run the code above in your browser using DataLab