Learn R Programming

Rtumblr (version 0.1.1)

get_blog_followed_by: Check If Followed By Blog This method can be used to check if one of your blogs is followed by another blog.

Description

Check If Followed By Blog This method can be used to check if one of your blogs is followed by another blog.

Usage

get_blog_followed_by(blog, query, app_credentials = NULL)

Value

logical

Arguments

blog

name of the blog

query

string. The name of the blog that may be following your blog

app_credentials

a named list containing the consumer key and consumer secret. If NULL, attempts to load from an env variable

Examples

Run this code
if (FALSE) {
# replace "your-blog-name" with your Tumblr username
get_blog_followed_by(blog = "your-blog-name", query = "blog-to-check")
}

Run the code above in your browser using DataLab