powered by
Check If Followed By Blog This method can be used to check if one of your blogs is followed by another blog.
get_blog_followed_by(blog, query, app_credentials = NULL)
logical
name of the blog
string. The name of the blog that may be following your blog
a named list containing the consumer key and consumer secret. If NULL, attempts to load from an env variable
if (FALSE) { # replace "your-blog-name" with your Tumblr username get_blog_followed_by(blog = "your-blog-name", query = "blog-to-check") }
Run the code above in your browser using DataLab