powered by
This method returns general information about the blog, such as the title, number of posts, and other high-level data.
get_blog_info(blog, api_key = NULL)
tibble of information about blog
name of the blog
app consumer key. If NULL, attempts to load from the environment variable RTUMBLR_TOKEN
if (FALSE) { get_blog_info("schochastics") }
Run the code above in your browser using DataLab