Retrieve Published Posts
Arguments
- blog
name of the blog
- limit
The number of results to return per request: 1-20
- offset
post index to start at
- n
maximum number of posts to retrieve across pages (default
limit, i.e. a single page). UseInfto retrieve all posts of the blog.- api_key
app consumer key. If NULL, attempts to load from the environment variable RTUMBLR_TOKEN
- ...
further parameters as described here: https://www.tumblr.com/docs/en/api/v2
Details
this function uses the new post format (npf: https://www.tumblr.com/docs/npf).
Pagination is handled automatically: it pages through offset up to the API cap of 1000,
then continues via the before timestamp, until n posts are collected or the blog is exhausted.