Returns information about the authenticating user, including which blogs they own.
Requires OAuth authentication (see rtumblr_auth()).
Returns information about the authenticating user, including which blogs they own.
Requires OAuth authentication (see rtumblr_auth()).